( cd usr/lib ; rm -rf libstartup-notification-1.so )
( cd usr/lib ; ln -sf libstartup-notification-1.so.0.0.0 libstartup-notification-1.so )
( cd usr/lib ; rm -rf libstartup-notification-1.so.0 )
( cd usr/lib ; ln -sf libstartup-notification-1.so.0.0.0 libstartup-notification-1.so.0 )
